@@ -94,7 +94,7 @@ eos
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :octavia_dashboard_package_name => 'python3-octavia-dashboard' }
         when 'RedHat'
