@@ -35,12 +35,13 @@ describe 'horizon' do
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :servername     => 'foo.example.com',
-          :listen_ssl     => false,
-          :wsgi_processes => facts[:os_workers],
-          :wsgi_threads   => '1',
-          :extra_params   => {},
-          :redirect_type  => 'permanent',
+          :servername                  => 'foo.example.com',
+          :listen_ssl                  => false,
+          :wsgi_processes              => facts[:os_workers],
+          :wsgi_threads                => '1',
+          :custom_wsgi_process_options => {},
+          :extra_params                => {},
+          :redirect_type               => 'permanent',
         })
       end
 
@@ -94,7 +95,7 @@ describe 'horizon' do
         params.merge!({
           :purge_conf_d_dir                 => true,
           :memoized_max_size_default        => 25,
-          :cache_backend                    => 'django.core.cache.backends.memcached.MemcachedCache',
+          :cache_backend                    => 'django.core.cache.backends.memcached.PyMemcacheCache',
           :cache_timeout                    => 300,
           :cache_options                    => {'SOCKET_TIMEOUT' => 1,'SERVER_RETRIES' => 1,'DEAD_RETRY' => 1},
           :cache_server_ip                  => '10.0.0.1',
@@ -175,7 +176,7 @@ describe 'horizon' do
           "            'SERVER_RETRIES': 1,",
           "            'SOCKET_TIMEOUT': 1,",
           "MEMOIZED_MAX_SIZE_DEFAULT = 25",
-          "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
+          "        'BACKEND': 'django.core.cache.backends.memcached.PyMemcacheCache',",
           "        'LOCATION': '10.0.0.1:11211',",
           "        'TIMEOUT': 300,",
           'SESSION_ENGINE = "django.contrib.sessions.backends.cache"',
@@ -268,22 +269,6 @@ describe 'horizon' do
       end
     end
 
-    context 'with overridden parameters, IPv6 cache_server_ip array and MemcachedCache' do
-      before do
-        params.merge!({
-          :cache_backend   => 'django.core.cache.backends.memcached.MemcachedCache',
-          :cache_server_ip => ['fd12:3456:789a:1::1','fd12:3456:789a:1::2'],
-        })
-      end
-
-      it 'generates local_settings.py' do
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          "        'BACKEND': 'django.core.cache.backends.memcached.MemcachedCache',",
-          "        'LOCATION': [ 'inet6:[fd12:3456:789a:1::1]:11211','inet6:[fd12:3456:789a:1::2]:11211', ],",
-        ])
-      end
-    end
-
     context 'with overridden parameters, IPv6 cache_server_ip array and PyMemcacheCache' do
       before do
         params.merge!({
@@ -328,32 +313,6 @@ describe 'horizon' do
       end
     end
 
-    context 'installs python memcache library when cache_backend is set to memcache' do
-      before do
-        params.merge!({
-          :cache_backend => 'django.core.cache.backends.memcached.MemcachedCache'
-        })
-      end
-
-      it {
-        is_expected.to contain_package('python-memcache').with(
-          :tag    => ['openstack'],
-          :name   => platforms_params[:memcache_package],
-        )
-      }
-    end
-
-    context 'does not install python memcache when manage_memcache_package set to false' do
-      before do
-        params.merge!({
-          :cache_backend           => 'django.core.cache.backends.memcached.MemcachedCache',
-          :manage_memcache_package => false
-        })
-      end
-
-      it { is_expected.not_to contain_package('python-memcache') }
-    end
-
     context 'installs python memcache library when cache_backend is set to pymemcache' do
       before do
         params.merge!({
@@ -408,15 +367,17 @@ describe 'horizon' do
 
     context 'with custom wsgi options' do
       before do
-        params.merge!( :wsgi_processes    => '30',
-                       :wsgi_threads      => '5',
-                       :access_log_format => 'common' )
+        params.merge!( :wsgi_processes              => '30',
+                       :wsgi_threads                => '5',
+                       :custom_wsgi_process_options => { 'python-env' => '/tmp/test' },
+                       :access_log_format           => 'common' )
       end
 
       it { should contain_class('horizon::wsgi::apache').with(
-        :wsgi_processes    => '30',
-        :wsgi_threads      => '5',
-        :access_log_format => 'common',
+        :wsgi_processes              => '30',
+        :wsgi_threads                => '5',
+        :custom_wsgi_process_options => { 'python-env' => '/tmp/test' },
+        :access_log_format           => 'common',
       )}
     end
 
@@ -829,7 +790,7 @@ describe 'horizon' do
   shared_examples_for 'horizon on Debian' do
     it 'refreshes horizon django cache' do
       is_expected.to contain_exec('refresh_horizon_django_compress').with({
-        :command     => '/usr/share/openstack-dashboard/manage.py compress --force',
+        :command     => ['/usr/share/openstack-dashboard/manage.py', 'compress', '--force'],
         :refreshonly => true,
       })
       is_expected.to contain_concat(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]')
@@ -860,7 +821,6 @@ describe 'horizon' do
               :package_name         => 'openstack-dashboard-apache',
               :root_url             => '/horizon',
               :root_path            => '/var/lib/openstack-dashboard',
-              :memcache_package     => 'python3-memcache',
               :pymemcache_package   => 'python3-pymemcache',
               :python_redis_package => 'python3-redis',
               :wsgi_user            => 'horizon',
@@ -873,7 +833,6 @@ describe 'horizon' do
               :package_name         => 'openstack-dashboard',
               :root_url             => '/horizon',
               :root_path            => '/var/lib/openstack-dashboard',
-              :memcache_package     => 'python3-memcache',
               :pymemcache_package   => 'python3-pymemcache',
               :python_redis_package => 'python3-redis',
               :wsgi_user            => 'horizon',
@@ -887,7 +846,6 @@ describe 'horizon' do
             :package_name         => 'openstack-dashboard',
             :root_url             => '/dashboard',
             :root_path            => '/usr/share/openstack-dashboard',
-            :memcache_package     => 'python3-memcached',
             :pymemcache_package   => 'python3-pymemcache',
             :python_redis_package => 'python3-redis',
             :wsgi_user            => 'apache',
