@@ -9,12 +9,13 @@ RSpec.configure do |c|
   c.alias_it_should_behave_like_to :it_raises, 'raises'
 
   c.module_path = File.join(fixture_path, 'modules')
-  c.manifest_dir = File.join(fixture_path, 'manifests')
 end
 
 def verify_concat_fragment_contents(subject, title, expected_lines)
   content = subject.resource('concat::fragment', title).send(:parameters)[:content]
-  expect(expected_lines & content.split("\n")).to eq(expected_lines)
+  expected_lines.each do |expected_line|
+    expect([expected_line] & content.split("\n")).to eq([expected_line])
+  end
 end
 
 at_exit { RSpec::Puppet::Coverage.report! }
